package nz.ac.massey.javaecs;
/**
 * ECS System class
 * This class stores entity-system registrations. These are
 * updated by SystemManager, but need a type to store the
 * data under.
 * 
 * All systems should inherit from this
 * 
 * Contributors:
 * Brychan Dempsey - brychand@hotmail.com
 * 
 */

import java.util.Set;
import java.util.BitSet;
import java.util.HashSet;

public abstract class ECSSystem{
    protected Set<Entity> entities = new HashSet<>();
    protected BitSet registrationSet;

    public BitSet getRegistrationSet;

    /**
     * Implement additional parameterised init() functions as required.
     * These should run once, when the system is first initialised.
     */
    public abstract void init();
    
    /**
     * Implement additional parameterised update() functions as required.
     * These should be run each game loop or otherwise sensible regular interval
     */
    public abstract void update();
}