package nz.ac.massey.javaecs;
/**
 * Entity class. 
 * Whilst an entity is just an Integer, and using Integer values
 * would be more performant (no function call), it is encapsulated to help
 * distinguish between entities and Integers.
 */
public class Entity {
    private int value;

    public Entity(int value){
        this.value = value;
    }

    public int getValue() {
        return value;
    }

    /**
     * Returns the int value wrapped as an entity.
     * Used to provide a distinction between creating a new entity, and
     * using an int value we assume is a valid entity.
     * 
     * Functionally, this is no different to creating a new entity.
     * 
     * @param value
     * @return
     */
    public static Entity asEntity(int value){
        return new Entity(value);
    }

    @Override
    public boolean equals(Object obj) 
    {
        if (obj instanceof Entity){
            return (this.getValue() == ((Entity)obj).getValue());
        }
        else if (obj instanceof Integer){
            return (this.value == (Integer)obj);
        }
        else return false;
    }

    @Override
    public int hashCode(){
        return value;
    }
}
